@@ -1,7 +1,7 @@
 /*
  * frogr-util.c -- Misc tools.
  *
- * Copyright (C) 2010-2017 Mario Sanchez Prada
+ * Copyright (C) 2010-2018 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -197,7 +197,7 @@ _show_message_dialog (GtkWindow *parent, const gchar *message, GtkMessageType ty
   g_signal_connect (G_OBJECT (dialog), "response",
                     G_CALLBACK (gtk_widget_destroy), dialog);
 
-  gtk_widget_show_all (dialog);
+  gtk_widget_show (dialog);
 }
 
 void
